@@ -1,4 +1,4 @@
-import sys,os,re,shutil,typing,itertools,operator,functools,math,warnings,functools,io
+import sys,os,re,typing,itertools,operator,functools,math,warnings,functools,io
 
 from operator import itemgetter,attrgetter
 from warnings import warn
